<?php
namespace ElementorFastGalleryMosaic;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.0.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function widget_scripts() {
		
		// Load WP jQuery if not included
		wp_enqueue_script('jquery');
		wp_register_script('removeWhitespace', plugins_url( 'assets/js/vendor/jquery.removeWhitespace.min.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script('collagePlus', plugins_url( 'assets/js/vendor/jquery.collagePlus.min.js', __FILE__ ), [ 'jquery' ], false, true );
		
		// Load main js script
		wp_enqueue_script( 'elementor-fast-gallery-mosaic-frontend', plugins_url( '/assets/js/fast-gallery.js', __FILE__ ), [ 'jquery' ], false, true );
		
		// Main
		wp_register_style( 'fastgallerymosaic-vc-main-style', plugins_url( '/assets/css/mosaic_style.css', __FILE__ ) );
		wp_register_style( 'fonts-vc',  plugins_url( 'assets/css/fonts.css', __FILE__ ));
		
		// PRETTYPHOTO		   
		wp_register_script('prettyPhoto', plugins_url( 'assets/js/vendor/jquery.prettyPhoto.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_style( 'prettyPhoto',  plugins_url( 'assets/css/prettyPhoto.css', __FILE__ ) );
		
		// MAGNIFIC POPUP
		wp_register_script('magnific-popup', plugins_url( 'assets/js/vendor/jquery.magnific-popup.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_style( 'magnific-popup',  plugins_url( 'assets/css/magnific-popup.css', __FILE__  ) );
				
		// LIGHT GALLERY
		wp_register_style( 'lightgallery',  plugins_url( 'assets/css/lightGallery.css', __FILE__ ) );
		wp_register_script( 'lightgallery',  plugins_url( 'assets/js/vendor/lightGallery.min.js' , __FILE__ ), [ 'jquery' ], false, true );		
				
		// ANIMATE
		wp_register_style( 'animations',  plugins_url( 'assets/css/animations.min.css', __FILE__ ) );
		wp_register_script( 'appear',  plugins_url( 'assets/js/vendor/appear.min.js' , __FILE__ ), [ 'jquery' ], false, true );	
		wp_register_script( 'animate',  plugins_url( 'assets/js/vendor/animations.min.js' , __FILE__ ), [ 'jquery' ], false, true );		
		
		// LAZY LOAD EFFECT
		wp_register_script( 'lazyload',  plugins_url( 'assets/js/vendor/jquery.lazyload.js' , __FILE__ ), [ 'jquery' ], false, true );				
		wp_register_script( 'imagesLoaded',  plugins_url( 'assets/js/vendor/imagesLoaded.js' , __FILE__ ), [ 'jquery' ], false, true );		
		if(\Elementor\Plugin::$instance->preview->is_preview_mode()) {
			wp_enqueue_script( 'removeWhitespace' );	
			wp_enqueue_script( 'collagePlus' );				
			wp_enqueue_style( 'fastgallerymosaic-vc-main-style' );
			wp_enqueue_style( 'fonts-vc' );
			wp_enqueue_style( 'prettyPhoto' );
			wp_enqueue_script( 'prettyPhoto' );
			wp_enqueue_style( 'magnific-popup' );
			wp_enqueue_script( 'magnific-popup' );
			wp_enqueue_style( 'lightgallery' );
			wp_enqueue_script( 'lightgallery' );
			wp_enqueue_style( 'animations' );
			wp_enqueue_script( 'appear' );			
			wp_enqueue_script( 'animate' );			
			wp_enqueue_script( 'lazyload' );			
			wp_enqueue_script( 'imagesLoaded' );
		}			
	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.0.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/FastGalleryMosaic/fast-gallery-mosaic.php' );
		require_once( __DIR__ . '/widgets/widgets-help-functions.php' );
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Fast_Gallery_Mosaic() );
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();
